@@ -15,9 +15,10 @@ function initialize {
     local profile=/.profile
     local partition_ids=/config.partids
 
-    test -f ${profile} || \
+    if test ! -f ${profile}; then
         warn "No profile setup found"
         warn "Settings from the kiwi description will be ignored"
+    fi
 
     test -f ${profile} && import_file ${profile}
 
@@ -256,6 +257,9 @@ if [ "$(get_partition_table_type "${disk}")" = 'gpt' ];then
     relocate_gpt_at_end_of_disk "${disk}"
 fi
 
+# wait for the root device to appear
+wait_for_storage_device "${root_device}"
+
 # resize disk partition table
 if lvm_system;then
     repart_lvm_disk || return
@@ -283,3 +287,6 @@ if lvm_system; then
 else
     resize_filesystem "$(get_root_map)"
 fi
+
+# wait for the root device to appear
+wait_for_storage_device "${root_device}"
